# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from pygments.style import Style

from pybemolle.tokens import *


__all__ = ['BemolleStyle']


class BemolleStyle(Style):
    """
    Colored chords theme.
    """

    background_color = '#f8f8f8'
    default_style = ''

    styles = {
        Whitespace: '#bbbbbb',
        Token: '#d0d0d0',

        Chord.C: '#00e800',
        Chord.D: '#006bff',
        Chord.E: '#8100ce',
        Chord.F: '#3d015b',
        Chord.G: '#d10400',
        Chord.A: '#ff8800',
        Chord.B: '#9af400',
        Chord.C.Flat: '#9af400',
        Chord.D.Flat: '#05feaa',
        Chord.E.Flat: '#2e01f0',
        Chord.F.Flat: '#8100ce',
        Chord.G.Flat: '#680351',
        Chord.A.Flat: '#e44202',
        Chord.B.Flat: '#ebff07',
        Chord.C.Sharp: '#05feaa',
        Chord.D.Sharp: '#2e01f0',
        Chord.E.Sharp: '#3d015b',
        Chord.F.Sharp: '#680351',
        Chord.G.Sharp: '#e44202',
        Chord.A.Sharp: '#ebff07',
        Chord.B.Sharp: '#00e800',

        Error: 'border: #ff0000'
    }



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from pygments.lexer import RegexLexer, bygroups, default
from pybemolle.tokens import *


__all__ = ['BemolleLexer']


class BemolleLexer(RegexLexer):
    name = 'Bemolle'
    aliases = ['bemolle', 'bmolle']
    filenames = ['*.bemolle', '*.bmolle']
    mimetypes = ['text/be-molle', 'text/b-molle',
                 'text/bemolle', 'text/bmolle']

    def include_chords(*tokens, alt=r'[#\*\+\w\\\/]*'):
        """Makes a list of tokens ready to include.
        Adds all possible tokens: major, minor, a symbols, etc.

        :param tuple tokens: tuple of (regex, pygments.token.Token)
        :param str alt: alteration symbols regexp
        :return list: list of tokens ready to include
        """
        result = [(r'(?:[ \t]|\\\n)+', Text)]
        for r, ch in tokens:
            result.append((r'\b({0}m)({1})'.format(r, alt),
                           bygroups(ch.Minor, ch.Alt)))
            result.append((r'\b({0})({1})'.format(r, alt),
                           bygroups(ch.Major, ch.Alt)))
        result.append(default('#pop'))
        return result

    tokens = {
        'root': [
            (r'(::|:lat)((?:\s|\\\s)+)', bygroups(Keyword.Namespace, Text),
             'chords_lat'),
            (r'(;;|;eng)((?:\s|\\\s)+)', bygroups(Keyword.Namespace, Text),
             'chords_eng'),
            (r'.', Text),
        ],
        'chords_lat': include_chords(
            (r'C#', Chord.C.Sharp),
            (r'D#', Chord.D.Sharp),
            (r'E#', Chord.E.Sharp),
            (r'F#', Chord.F.Sharp),
            (r'G#', Chord.G.Sharp),
            (r'A#', Chord.A.Sharp),
            (r'H#', Chord.B.Sharp),
            (r'Cb', Chord.C.Flat),
            (r'Db', Chord.D.Flat),
            (r'Eb', Chord.E.Flat),
            (r'Fb', Chord.F.Flat),
            (r'Gb', Chord.G.Flat),
            (r'Ab', Chord.A.Flat),
            (r'B', Chord.B.Flat),
            (r'C', Chord.C),
            (r'D', Chord.D),
            (r'E', Chord.E),
            (r'F', Chord.F),
            (r'G', Chord.G),
            (r'A', Chord.A),
            (r'H', Chord.B),
        ),
        'chords_eng': include_chords(
            (r'C#', Chord.C.Sharp),
            (r'D#', Chord.D.Sharp),
            (r'E#', Chord.E.Sharp),
            (r'F#', Chord.F.Sharp),
            (r'G#', Chord.G.Sharp),
            (r'A#', Chord.A.Sharp),
            (r'B#', Chord.B.Sharp),
            (r'Cb', Chord.C.Flat),
            (r'Db', Chord.D.Flat),
            (r'Eb', Chord.E.Flat),
            (r'Fb', Chord.F.Flat),
            (r'Gb', Chord.G.Flat),
            (r'Ab', Chord.A.Flat),
            (r'Bb', Chord.B.Flat),
            (r'C', Chord.C),
            (r'D', Chord.D),
            (r'E', Chord.E),
            (r'F', Chord.F),
            (r'G', Chord.G),
            (r'A', Chord.A),
            (r'B', Chord.B),
        ),
    }



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from pygments.token import *


Music = Token.Music
Chord = Music.Chord

# put our own tokens into style sheet
# "mus-" prefix here music means
STANDARD_TYPES.update({
    Chord.C: 'mus-c',
    Chord.D: 'mus-d',
    Chord.E: 'mus-e',
    Chord.F: 'mus-f',
    Chord.G: 'mus-g',
    Chord.A: 'mus-a',
    Chord.B: 'mus-b',
    Chord.C.Flat: 'mus-cb',
    Chord.D.Flat: 'mus-db',
    Chord.E.Flat: 'mus-eb',
    Chord.F.Flat: 'mus-fb',
    Chord.G.Flat: 'mus-gb',
    Chord.A.Flat: 'mus-ab',
    Chord.B.Flat: 'mus-bb',
    Chord.C.Sharp: 'mus-cs',
    Chord.D.Sharp: 'mus-ds',
    Chord.E.Sharp: 'mus-es',
    Chord.F.Sharp: 'mus-fs',
    Chord.G.Sharp: 'mus-gs',
    Chord.A.Sharp: 'mus-as',
    Chord.B.Sharp: 'mus-bs',
    Chord.C.Major: 'mus-c mus-maj',
    Chord.D.Major: 'mus-d mus-maj',
    Chord.E.Major: 'mus-e mus-maj',
    Chord.F.Major: 'mus-f mus-maj',
    Chord.G.Major: 'mus-g mus-maj',
    Chord.A.Major: 'mus-a mus-maj',
    Chord.B.Major: 'mus-b mus-maj',
    Chord.C.Flat.Major: 'mus-cb mus-maj',
    Chord.D.Flat.Major: 'mus-db mus-maj',
    Chord.E.Flat.Major: 'mus-eb mus-maj',
    Chord.F.Flat.Major: 'mus-fb mus-maj',
    Chord.G.Flat.Major: 'mus-gb mus-maj',
    Chord.A.Flat.Major: 'mus-ab mus-maj',
    Chord.B.Flat.Major: 'mus-bb mus-maj',
    Chord.C.Sharp.Major: 'mus-cs mus-maj',
    Chord.D.Sharp.Major: 'mus-ds mus-maj',
    Chord.E.Sharp.Major: 'mus-es mus-maj',
    Chord.F.Sharp.Major: 'mus-fs mus-maj',
    Chord.G.Sharp.Major: 'mus-gs mus-maj',
    Chord.A.Sharp.Major: 'mus-as mus-maj',
    Chord.B.Sharp.Major: 'mus-bs mus-maj',
    Chord.C.Minor: 'mus-c mus-min',
    Chord.D.Minor: 'mus-d mus-min',
    Chord.E.Minor: 'mus-e mus-min',
    Chord.F.Minor: 'mus-f mus-min',
    Chord.G.Minor: 'mus-g mus-min',
    Chord.A.Minor: 'mus-a mus-min',
    Chord.B.Minor: 'mus-b mus-min',
    Chord.C.Flat.Minor: 'mus-cb mus-min',
    Chord.D.Flat.Minor: 'mus-db mus-min',
    Chord.E.Flat.Minor: 'mus-eb mus-min',
    Chord.F.Flat.Minor: 'mus-fb mus-min',
    Chord.G.Flat.Minor: 'mus-gb mus-min',
    Chord.A.Flat.Minor: 'mus-ab mus-min',
    Chord.B.Flat.Minor: 'mus-bb mus-min',
    Chord.C.Sharp.Minor: 'mus-cs mus-min',
    Chord.D.Sharp.Minor: 'mus-ds mus-min',
    Chord.E.Sharp.Minor: 'mus-es mus-min',
    Chord.F.Sharp.Minor: 'mus-fs mus-min',
    Chord.G.Sharp.Minor: 'mus-gs mus-min',
    Chord.A.Sharp.Minor: 'mus-as mus-min',
    Chord.B.Sharp.Minor: 'mus-bs mus-min',
    Chord.C.Alt: 'mus-c mus-alt',
    Chord.D.Alt: 'mus-d mus-alt',
    Chord.E.Alt: 'mus-e mus-alt',
    Chord.F.Alt: 'mus-f mus-alt',
    Chord.G.Alt: 'mus-g mus-alt',
    Chord.A.Alt: 'mus-a mus-alt',
    Chord.B.Alt: 'mus-b mus-alt',
    Chord.C.Flat.Alt: 'mus-cb mus-alt',
    Chord.D.Flat.Alt: 'mus-db mus-alt',
    Chord.E.Flat.Alt: 'mus-eb mus-alt',
    Chord.F.Flat.Alt: 'mus-fb mus-alt',
    Chord.G.Flat.Alt: 'mus-gb mus-alt',
    Chord.A.Flat.Alt: 'mus-ab mus-alt',
    Chord.B.Flat.Alt: 'mus-bb mus-alt',
    Chord.C.Sharp.Alt: 'mus-cs mus-alt',
    Chord.D.Sharp.Alt: 'mus-ds mus-alt',
    Chord.E.Sharp.Alt: 'mus-es mus-alt',
    Chord.F.Sharp.Alt: 'mus-fs mus-alt',
    Chord.G.Sharp.Alt: 'mus-gs mus-alt',
    Chord.A.Sharp.Alt: 'mus-as mus-alt',
    Chord.B.Sharp.Alt: 'mus-bs mus-alt',
})



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
PyBemolle
~~~~~~~~~

PyBemolle is a Pygments library plugin made to colorize guitar chords.

Highlights are:

* both Latin and English chords notations
* flat and sharp chords have different styles
* major and minor chords have different styles
* support for alteration part like: Gm6, F7+, F#m7, Cmaj7, Cmaj7/E \
    alteration part has a separate style

:copyright: Copyright 2019-2020 by the Ihor Nahuliak, see AUTHORS.
:license: GNU General Public License v3 (GPLv3), see LICENSE for details.
"""
import os
import sys
from shutil import rmtree

try:
    from setuptools import setup, find_packages, Command
    have_setuptools = True
except ImportError:
    from distutils.core import setup

    def find_packages(*args, **kwargs):
        return [
            'pybemolle',
            'pybemolle.lexers',
            'pybemolle.formatters',
            'pybemolle.styles',
            'pybemolle.filters',
        ]

    have_setuptools = False


__author__ = 'Ihor Nahuliak'
__author_email__ = 'ihor.nahuliak@gmail.com'
__url__ = 'https://github.com/ihor-nahuliak/pybemolle'
__license__ = 'GPL v.3.0'
__version__ = '0.0.1'

__python_requires__ = [
    '>=2.7',
    '!=3.0.*',
    '!=3.1.*',
    '!=3.2.*',
    '!=3.3.*',
    '!=3.4.*',
]
__install_requires__ = [
    'pygments>=2.4.2',
]
__extras_requires__ = {
    'dev': ['setuptools', 'twine'],
}


ROOT = os.path.abspath(os.path.dirname(__file__))


# Note: To use the 'upload' functionality of this file, you must:
# $ pip install twine --dev
if have_setuptools:

    class UploadCommand(Command):
        """Support of `setup.py upload`."""

        description = 'Build and publish the package.'
        user_options = []

        @staticmethod
        def status(s):
            # print in bold font
            print('\033[1m{0}\033[0m'.format(s))

        def initialize_options(self):
            pass

        def finalize_options(self):
            pass

        def run(self):
            try:
                self.status('Removing previous builds…')
                rmtree(os.path.join(ROOT, 'dist'))
            except OSError:
                pass

            self.status('Building Source and Wheel (universal) distribution…')
            os.system('{0} setup.py sdist bdist_wheel '
                      '--universal'.format(sys.executable))

            self.status('Uploading the package to PyPI via Twine…')
            os.system('twine upload dist/*')

            # self.status('Pushing git tags…')
            # os.system('git tag v{0}'.format(__version__))
            # os.system('git push --tags')

            sys.exit()


    cmdclass = {'upload': UploadCommand}

else:
    cmdclass = None


setup(
    name='pybemolle',
    version=__version__,
    description=__doc__,
    # long_description=__doc__,
    # long_description_content_type='text/plain',
    author=__author__,
    author_email=__author_email__,
    url=__url__,
    packages=find_packages(exclude=['tests']),
    entry_points="""
    [pygments.lexers]
    bemolle = pybemolle:BemolleLexer
    [pygments.styles]
    bemolle = pybemolle:BemolleStyle
    """,
    platforms='any',
    zip_safe=False,
    include_package_data=True,
    python_requires=', '.join(__python_requires__),
    install_requires=__install_requires__,
    extras_require=__extras_requires__,
    license=__license__,
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Development Status :: 1 - Planning',
    ],
    # $ setup.py publish support.
    cmdclass=cmdclass,
)
